/*!
 * Cropper v2.3.0
 * https://github.com/fengyuanchen/cropper
 *
 * Copyright (c) 2014-2016 Fengyuan Chen and contributors
 * Released under the MIT license
 *
 * Date: 2016-02-22T02:13:13.332Z
 */
.cropper-container {
  font-size: 0;
  line-height: 0;

  position: relative;

  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;

  direction: ltr !important;
  -ms-touch-action: none;
      touch-action: none;
  -webkit-tap-highlight-color: transparent;
  -webkit-touch-callout: none;
}

.cropper-container img {
  display: block;

  width: 100%;
  min-width: 0 !important;
  max-width: none !important;
  height: 100%;
  min-height: 0 !important;
  max-height: none !important;

  image-orientation: 0deg !important;
}

.cropper-wrap-box,
.cropper-canvas,
.cropper-drag-box,
.cropper-crop-box,
.cropper-modal {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}

.cropper-wrap-box {
  overflow: hidden;
}

.cropper-drag-box {
  opacity: 0;
  background-color: #fff;

  filter: alpha(opacity=0);
}

.cropper-modal {
  opacity: .5;
  background-color: #000;

  filter: alpha(opacity=50);
}

.cropper-view-box {
  display: block;
  overflow: hidden;

  width: 100%;
  height: 100%;

  outline: 1px solid #39f;
  outline-color: rgba(51, 153, 255, .75);
}

.cropper-dashed {
  position: absolute;

  display: block;

  opacity: .5;
  border: 0 dashed #eee;

  filter: alpha(opacity=50);
}

.cropper-dashed.dashed-h {
  top: 33.33333%;
  left: 0;

  width: 100%;
  height: 33.33333%;

  border-top-width: 1px;
  border-bottom-width: 1px;
}

.cropper-dashed.dashed-v {
  top: 0;
  left: 33.33333%;

  width: 33.33333%;
  height: 100%;

  border-right-width: 1px;
  border-left-width: 1px;
}

.cropper-center {
  position: absolute;
  top: 50%;
  left: 50%;

  display: block;

  width: 0;
  height: 0;

  opacity: .75;

  filter: alpha(opacity=75);
}

.cropper-center:before,
.cropper-center:after {
  position: absolute;

  display: block;

  content: ' ';

  background-color: #eee;
}

.cropper-center:before {
  top: 0;
  left: -3px;

  width: 7px;
  height: 1px;
}

.cropper-center:after {
  top: -3px;
  left: 0;

  width: 1px;
  height: 7px;
}

.cropper-face,
.cropper-line,
.cropper-point {
  position: absolute;

  display: block;

  width: 100%;
  height: 100%;

  opacity: .1;

  filter: alpha(opacity=10);
}

.cropper-face {
  top: 0;
  left: 0;

  background-color: #fff;
}

.cropper-line {
  background-color: #39f;
}

.cropper-line.line-e {
  top: 0;
  right: -3px;

  width: 5px;

  cursor: e-resize;
}

.cropper-line.line-n {
  top: -3px;
  left: 0;

  height: 5px;

  cursor: n-resize;
}

.cropper-line.line-w {
  top: 0;
  left: -3px;

  width: 5px;

  cursor: w-resize;
}

.cropper-line.line-s {
  bottom: -3px;
  left: 0;

  height: 5px;

  cursor: s-resize;
}

.cropper-point {
  width: 5px;
  height: 5px;

  opacity: .75;
  background-color: #39f;

  filter: alpha(opacity=75);
}

.cropper-point.point-e {
  top: 50%;
  right: -3px;

  margin-top: -3px;

  cursor: e-resize;
}

.cropper-point.point-n {
  top: -3px;
  left: 50%;

  margin-left: -3px;

  cursor: n-resize;
}

.cropper-point.point-w {
  top: 50%;
  left: -3px;

  margin-top: -3px;

  cursor: w-resize;
}

.cropper-point.point-s {
  bottom: -3px;
  left: 50%;

  margin-left: -3px;

  cursor: s-resize;
}

.cropper-point.point-ne {
  top: -3px;
  right: -3px;

  cursor: ne-resize;
}

.cropper-point.point-nw {
  top: -3px;
  left: -3px;

  cursor: nw-resize;
}

.cropper-point.point-sw {
  bottom: -3px;
  left: -3px;

  cursor: sw-resize;
}

.cropper-point.point-se {
  right: -3px;
  bottom: -3px;

  width: 20px;
  height: 20px;

  cursor: se-resize;

  opacity: 1;

  filter: alpha(opacity=100);
}

.cropper-point.point-se:before {
  position: absolute;
  right: -50%;
  bottom: -50%;

  display: block;

  width: 200%;
  height: 200%;

  content: ' ';

  opacity: 0;
  background-color: #39f;

  filter: alpha(opacity=0);
}

@media (min-width: 768px) {
  .cropper-point.point-se {
    width: 15px;
    height: 15px;
  }
}

@media (min-width: 992px) {
  .cropper-point.point-se {
    width: 10px;
    height: 10px;
  }
}

@media (min-width: 1200px) {
  .cropper-point.point-se {
    width: 5px;
    height: 5px;

    opacity: .75;

    filter: alpha(opacity=75);
  }
}

.cropper-invisible {
  opacity: 0;

  filter: alpha(opacity=0);
}

.cropper-bg {
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQMAAAAlPW0iAAAAA3NCSVQICAjb4U/gAAAABlBMVEXMzMz////TjRV2AAAACXBIWXMAAArrAAAK6wGCiw1aAAAAHHRFWHRTb2Z0d2FyZQBBZG9iZSBGaXJld29ya3MgQ1M26LyyjAAAABFJREFUCJlj+M/AgBVhF/0PAH6/D/HkDxOGAAAAAElFTkSuQmCC');
}

.cropper-hide {
  position: absolute;

  display: block;

  width: 0;
  height: 0;
}

.cropper-hidden {
  display: none !important;
}

.cropper-move {
  cursor: move;
}

.cropper-crop {
  cursor: crosshair;
}

.cropper-disabled .cropper-drag-box,
.cropper-disabled .cropper-face,
.cropper-disabled .cropper-line,
.cropper-disabled .cropper-point {
  cursor: not-allowed;
}
.pat-imagecrop-scaleselect .label{display:inline;padding:.2em .6em .3em;font-size:75%;font-weight:bold;line-height:1;color:#fff;text-align:center;white-space:nowrap;vertical-align:baseline;border-radius:.25em}a.pat-imagecrop-scaleselect .label:hover,a.pat-imagecrop-scaleselect .label:focus{color:#fff;text-decoration:none;cursor:pointer}.pat-imagecrop-scaleselect .label:empty{display:none}.btn .pat-imagecrop-scaleselect .label{position:relative;top:-1px}.pat-imagecrop-scaleselect .label-default{background-color:#777}.pat-imagecrop-scaleselect .label-default[href]:hover,.pat-imagecrop-scaleselect .label-default[href]:focus{background-color:#5e5e5e}.pat-imagecrop-scaleselect .label-primary{background-color:#337ab7}.pat-imagecrop-scaleselect .label-primary[href]:hover,.pat-imagecrop-scaleselect .label-primary[href]:focus{background-color:#286090}.pat-imagecrop-scaleselect .label-success{background-color:#5cb85c}.pat-imagecrop-scaleselect .label-success[href]:hover,.pat-imagecrop-scaleselect .label-success[href]:focus{background-color:#449d44}.pat-imagecrop-scaleselect .label-info{background-color:#5bc0de}.pat-imagecrop-scaleselect .label-info[href]:hover,.pat-imagecrop-scaleselect .label-info[href]:focus{background-color:#31b0d5}.pat-imagecrop-scaleselect .label-warning{background-color:#f0ad4e}.pat-imagecrop-scaleselect .label-warning[href]:hover,.pat-imagecrop-scaleselect .label-warning[href]:focus{background-color:#ec971f}.pat-imagecrop-scaleselect .label-danger{background-color:#d9534f}.pat-imagecrop-scaleselect .label-danger[href]:hover,.pat-imagecrop-scaleselect .label-danger[href]:focus{background-color:#c9302c}.pat-imagecrop-scaleselect.autotabs{padding:1em}.pat-imagecrop-scaleselect div.items.scaleselector{margin-top:5em;padding-left:0;padding-right:0}.pat-imagecrop-scaleselect div.items.scaleselector .list-group{padding-left:0}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item{position:relative;display:block;padding:10px 15px;margin-bottom:-1px;background:#f2f1f1;border:1px solid #ccc;cursor:pointer}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item div.preview-container div.crop-preview{overflow:hidden}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item div.preview-container div.crop-preview img{max-width:100%}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item:first-child{border-top-right-radius:4px;border-top-left-radius:4px}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item:last-child{border-bottom-right-radius:4px;border-bottom-left-radius:4px}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item.active{background:white;cursor:default}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item.active:first-child{border-top-right-radius:0}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item.active:last-child{border-botton-right-radius:0}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item.inactive div.preview-container{display:none}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item .label{float:right}.pat-imagecrop-scaleselect div.items.scaleselector .list-group .list-group-item.impossible{cursor:default}.pat-imagecrop-scaleselect #fieldset-image{width:100%}.pat-imagecrop-scaleselect div.allcroppingarea{padding:1em 1em 0 1em}.pat-imagecrop-scaleselect div.singlecroppingarea{padding-left:1.5em;padding-right:0}.pat-imagecrop-scaleselect div.singlecroppingarea .pat-image-crop{padding-left:15px;padding-right:15px}.pat-imagecrop-scaleselect div.singlecroppingarea.active{display:block}.pat-imagecrop-scaleselect div.singlecroppingarea.inactive{display:none}.pat-imagecrop-scaleselect div.singlecroppingarea .pat-image-cropper{padding:4px 0}.pat-imagecrop-scaleselect div.singlecroppingarea .pat-image-cropper img{width:100%}.pat-imagecrop-scaleselect div.singlecroppingarea .scale-info{padding:0 6px 10px 0}.pat-imagecrop-scaleselect div.singlecroppingarea .scale-info .nowrap{white-space:nowrap}.pat-imagecrop-scaleselect div.singlecroppingarea .crop-buttons{padding-right:0}.pat-imagecrop-scaleselect nav{float:none;padding:0;margin:0 0 .3em 0;border:0;border-bottom:1px solid #DDD;background:#EEE none repeat scroll 0 0;-webkit-border-radius:4px 4px 0 0;-moz-border-radius:4px 4px 0 0;-ie-border-radius:4px 4px 0 0;-o-border-radius:4px 4px 0 0;border-radius:4px 4px 0 0}.pat-imagecrop-scaleselect nav:after{content:"";display:table;line-height:0}.pat-imagecrop-scaleselect nav a{display:inline-block;margin:.5em 0 -1px .5em;padding:12px 12px;text-decoration:none;-webkit-border-radius:4px 4px 0 0;-moz-border-radius:4px 4px 0 0;-ie-border-radius:4px 4px 0 0;-o-border-radius:4px 4px 0 0;border-radius:4px 4px 0 0;background-color:#FFF;height:50px}.pat-imagecrop-scaleselect nav a img{-webkit-border-radius:3px;-moz-border-radius:3px;-ie-border-radius:3px;-o-border-radius:3px;border-radius:3px;max-width:100%;max-height:100%;width:auto;height:auto}.pat-imagecrop-scaleselect nav a:focus{outline-style:none}.pat-imagecrop-scaleselect nav a.active{border:1px solid #DDD;border-bottom-color:#FFF;color:#555555;cursor:default}.pat-imagecrop-scaleselect nav a.inactive{border:1px solid #EEE;border-bottom-color:#DDD}.pat-imagecrop-scaleselect nav a.inactive:hover{border:1px solid #DDD;border-bottom-color:#FFF}.pat-imagecrop-scaleselect nav button.save-all{margin:1em}.pat-imagecrop-scaleselect fieldset.inactive{display:none}@site Path:/;@site Path: /;/*# sourceMappingURL=imagecropping.css.map */